==> graphql-web-lite-16.6.0-1.tgz: package/utilities/astFromValue.js <==
var jsutils_inspect = require("../jsutils/inspect.js");

var jsutils_invariant = require("../jsutils/invariant.js");

var jsutils_isIterableObject = require("../jsutils/isIterableObject.js");

var jsutils_isObjectLike = require("../jsutils/isObjectLike.js");

var type_definition = require("../type/definition.js");

var type_scalars = require("../type/scalars.js");

var shared = require("../shared.js");

const integerStringRegExp = /^-?(?:0|[1-9][0-9]*)$/;

exports.astFromValue = function astFromValue(value, type) {
  if (type_definition.isNonNullType(type)) {
    const astValue = astFromValue(value, type.ofType);
    if ((null == astValue ? void 0 : astValue.kind) === shared.e.NULL) {
      return null;
    }
    return astValue;
  }
  if (null === value) {
    return {
      kind: shared.e.NULL
    };
  }
  if (void 0 === value) {
    return null;
  }
  if (type_definition.isListType(type)) {
    const itemType = type.ofType;
    if (jsutils_isIterableObject.isIterableObject(value)) {
      const valuesNodes = [];
      for (const item of value) {
        const itemNode = astFromValue(item, itemType);
        if (null != itemNode) {
          valuesNodes.push(itemNode);
        }
      }
      return {
        kind: shared.e.LIST,
        values: valuesNodes
      };
    }
    return astFromValue(value, itemType);
  }
  if (type_definition.isInputObjectType(type)) {
    if (!jsutils_isObjectLike.isObjectLike(value)) {
      return null;
    }
    const fieldNodes = [];
    for (const field of Object.values(type.getFields())) {
      const fieldValue = astFromValue(value[field.name], field.type);
      if (fieldValue) {
        fieldNodes.push({
          kind: shared.e.OBJECT_FIELD,
          name: {
            kind: shared.e.NAME,
            value: field.name
          },
          value: fieldValue
        });
      }
    }
    return {
      kind: shared.e.OBJECT,
      fields: fieldNodes
    };
  }
  if (type_definition.isLeafType(type)) {
    const serialized = type.serialize(value);
    if (null == serialized) {
      return null;
    }
    if ("boolean" == typeof serialized) {
      return {
        kind: shared.e.BOOLEAN,
        value: serialized
      };
    }
    if ("number" == typeof serialized && Number.isFinite(serialized)) {
      const stringNum = String(serialized);
      return integerStringRegExp.test(stringNum) ? {
        kind: shared.e.INT,
        value: stringNum
      } : {
        kind: shared.e.FLOAT,
        value: stringNum
      };
    }
    if ("string" == typeof serialized) {
      if (type_definition.isEnumType(type)) {
        return {
          kind: shared.e.ENUM,
          value: serialized
        };
      }
      if (type === type_scalars.GraphQLID && integerStringRegExp.test(serialized)) {
        return {
          kind: shared.e.INT,
          value: serialized
        };
      }
      return {
        kind: shared.e.STRING,
        value: serialized
      };
    }
    throw new TypeError(`Cannot convert value to AST: ${jsutils_inspect.inspect(serialized)}.`);
  }
  jsutils_invariant.invariant(!1);
};

==> graphql-web-lite-16.6.0-4.tgz: package/utilities/astFromValue.js <==
var jsutils_inspect = require("../jsutils/inspect.js");

var jsutils_invariant = require("../jsutils/invariant.js");

var jsutils_isIterableObject = require("../jsutils/isIterableObject.js");

var jsutils_isObjectLike = require("../jsutils/isObjectLike.js");

var type_definition = require("../type/definition.js");

var type_scalars = require("../type/scalars.js");

var graphql_web = require("@0no-co/graphql.web");

const integerStringRegExp = /^-?(?:0|[1-9][0-9]*)$/;

exports.astFromValue = function astFromValue(value, type) {
  if (type_definition.isNonNullType(type)) {
    const astValue = astFromValue(value, type.ofType);
    if ((null == astValue ? void 0 : astValue.kind) === graphql_web.Kind.NULL) {
      return null;
    }
    return astValue;
  }
  if (null === value) {
    return {
      kind: graphql_web.Kind.NULL
    };
  }
  if (void 0 === value) {
    return null;
  }
  if (type_definition.isListType(type)) {
    const itemType = type.ofType;
    if (jsutils_isIterableObject.isIterableObject(value)) {
      const valuesNodes = [];
      for (const item of value) {
        const itemNode = astFromValue(item, itemType);
        if (null != itemNode) {
          valuesNodes.push(itemNode);
        }
      }
      return {
        kind: graphql_web.Kind.LIST,
        values: valuesNodes
      };
    }
    return astFromValue(value, itemType);
  }
  if (type_definition.isInputObjectType(type)) {
    if (!jsutils_isObjectLike.isObjectLike(value)) {
      return null;
    }
    const fieldNodes = [];
    for (const field of Object.values(type.getFields())) {
      const fieldValue = astFromValue(value[field.name], field.type);
      if (fieldValue) {
        fieldNodes.push({
          kind: graphql_web.Kind.OBJECT_FIELD,
          name: {
            kind: graphql_web.Kind.NAME,
            value: field.name
          },
          value: fieldValue
        });
      }
    }
    return {
      kind: graphql_web.Kind.OBJECT,
      fields: fieldNodes
    };
  }
  if (type_definition.isLeafType(type)) {
    const serialized = type.serialize(value);
    if (null == serialized) {
      return null;
    }
    if ("boolean" == typeof serialized) {
      return {
        kind: graphql_web.Kind.BOOLEAN,
        value: serialized
      };
    }
    if ("number" == typeof serialized && Number.isFinite(serialized)) {
      const stringNum = String(serialized);
      return integerStringRegExp.test(stringNum) ? {
        kind: graphql_web.Kind.INT,
        value: stringNum
      } : {
        kind: graphql_web.Kind.FLOAT,
        value: stringNum
      };
    }
    if ("string" == typeof serialized) {
      if (type_definition.isEnumType(type)) {
        return {
          kind: graphql_web.Kind.ENUM,
          value: serialized
        };
      }
      if (type === type_scalars.GraphQLID && integerStringRegExp.test(serialized)) {
        return {
          kind: graphql_web.Kind.INT,
          value: serialized
        };
      }
      return {
        kind: graphql_web.Kind.STRING,
        value: serialized
      };
    }
    throw new TypeError(`Cannot convert value to AST: ${jsutils_inspect.inspect(serialized)}.`);
  }
  jsutils_invariant.invariant(!1);
};
